import { FormSchema, BasicColumn } from '/@/components/Table';
import { optionsListApi } from '/@/api/tigerapi/wms/transfer';
import { h, unref } from 'vue';
import { Switch } from 'ant-design-vue';
import { Tag } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
import { Button } from '/@/components/Button';
const { t: bt } = useI18n('WMS.Transfer');
const { getLocale } = useLocale();
export const columns: BasicColumn[] = [
  {
    title: bt('单据代码'),
    resizable: true,
    sorter: true,
    dataIndex: 'BILLCODE',
    width: 200,
  },
  {
    title: bt('单据日期'),
    resizable: true,
    sorter: true,
    dataIndex: 'BILLDATE',
    width: 180,
  },
  {
    title: bt('创建时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: bt('操作时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'UPDATE_TIME',
    width: 180,
  },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case -1:
          text = bt('手动新增');
          color = 'blue';
          break;
        case 0:
          text = bt('新增');
          color = 'blue';
          break;
        case 1:
          text = bt('作业中');
          color = '#C2C247';
          break;
        case 2:
          text = bt('完成');
          color = '#C2C247';
          break;
        case 3:
          text = bt('调拨完成');
          color = 'green';
          break;
          case 4:
            text = bt('手动下架完成');
            color = 'green';
            break;
            case 5:
              text = bt('调出');
              color = 'green';
              break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: bt('调出仓库'),
    resizable: true,
    sorter: true,
    dataIndex: 'OUTWAREHOUSECODE',
    width: 180,
  },
  {
    title: bt('调入仓库'),
    resizable: true,
    sorter: true,
    dataIndex: 'INWAREHOUSECODE',
    width: 180,
  },
  {
    title: bt('T100单据代码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ERP_BILL_CODE',
    width: 180,
  },
  {
    title: bt('创建人'),
    resizable:true,
    width: 180,
    dataIndex: 'CREATE_USER',
  },
  // {
  //   title: bt('创建时间'),
  //   resizable:true,
  //   width: 180,
  // },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: bt('单据代码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'BILLDATE',
    label: bt('单据日期'),
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  }
];
//调拨单(WMS)明细
export const columns_D: BasicColumn[] = [
  {
    title: bt('组织机构授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_ORG',
    width: 200,
    ifShow: false,
  },
  {
    title: bt('生产单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_PROD',
    width: 200,
    ifShow: false,
  },
  {
    title: bt('仓库单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_WH',
    width: 200,
    ifShow: false,
  },
  {
    title: bt('序号'),
    resizable: true,
    sorter: true,
    dataIndex: 'BILLLINE',
    width: 100,
  },
  // {
  //   title: bt('单据代码'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'BILLCODE',
  //   width: 200,
  // },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: bt('需求数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'PRQTY',
    width: 100,
  },
  {
    title: bt('发出数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'OUTQTY',
    width: 100,
  },
  {
    title: bt('转入数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'INQTY',
    width: 100,
  },
  {
    title: bt('物料名称'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_NAME',
    width: 200,
  },
  {
    title: bt('操作时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  // {
  //   title: bt('状态'),
  //   resizable:true,
  //   width: 180,
  //   customRender: ({ record }) => {
  //     console.log('record', record);
  //     const status = record.LINESTATUS;
  //     let text = '';
  //     let color = '';
  //     switch (status) {
  //       case 0:
  //         text = bt('新增');
  //         color = 'blue';
  //         break;
  //       case 1:
  //         text = bt('作业中');
  //         color = '#C2C247';
  //         break;
  //       case 2:
  //         text = bt('完成');
  //         color = '#C2C247';
  //         break;
  //       case 3:
  //         text = bt('调拨完成');
  //         color = 'green';
  //         break;
  //       default:
  //         break;
  //     }
  //     return h(Tag, { color: color }, () => text);
  //   },
  // },
  // {
  //   title: bt('出库仓库'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'OUTWAREHOUSECODE',
  //   width: 200,
  // },
  // {
  //   title: bt('入库仓库'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'INWAREHOUSECODE',
  //   width: 200,
  // },
  // {
  //   title: bt('出库数量'),
  //   resizable:true,
  //   width: 200,
  // },
  // {
  //   title: bt('入库数量'),
  //   resizable:true,
  //   width: 200,
  // },
  // {
  //   title: bt('需求数量'),
  //   resizable:true,
  //   width: 200,
  // },
]
//调拨单(WMS)明细
export const columns_ADD: BasicColumn[] = [
  {
    title: bt('组织机构授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_ORG',
    width: 200,
    ifShow: false,
  },
  {
    title: bt('生产单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_PROD',
    width: 200,
    ifShow: false,
  },
  {
    title: bt('仓库单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_WH',
    width: 200,
    ifShow: false,
  },
  {
    title: bt('序号'),
    resizable: true,
    sorter: true,
    editRow: true,
    editable:true,
    dataIndex: 'BILLLINE',
    width: 100,
  },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: bt('需求数量'),
    resizable: true,
    editRule: true,
    editComponent: 'InputNumber',
    sorter: true,
    editRow: true,
    dataIndex: 'PRQTY',
    width: 100,
  },
  // {
  //   title: bt('发出数量'),
  //   resizable: true,
  //   editRule: true,
  //   editComponent: 'InputNumber',
  //   sorter: true,
  //   editRow: true,
  //   dataIndex: 'OUTQTY',
  //   width: 100,
  // },
  // {
  //   title: bt('转入数量'),
  //   resizable: true,
  //   editRule: true,
  //   editComponent: 'InputNumber',
  //   sorter: true,
  //   editRow: true,
  //   dataIndex: 'INQTY',
  //   width: 100,
  // },
  {
    title: bt('物料名称'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_NAME',
    width: 200,
  },
  {
    title: bt('规格'),
    resizable: true,
    editable:true,
    sorter: true,
    editRow: true,
    dataIndex: 'UNITCODE',
    width: 200,
  },
  {
    title: bt('操作时间'),
    resizable: true,
    editComponent: 'DatePicker',
      editComponentProps: {
        valueFormat: 'YYYY-MM-DD HH:mm:ss',
        format: 'YYYY-MM-DD HH:mm:ss',
      },
    sorter: true,
    editRow: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  }
]

export const columns_S: BasicColumn[] = [
  {
    title: bt('组织机构授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_ORG',
    width: 200,
    ifShow: false
  },
  {
    title: bt('生产单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_PROD',
    width: 200,
    ifShow: false
  },
  {
    title: bt('仓库单元授权标识字段'),
    resizable: true,
    sorter: true,
    dataIndex: 'AUTH_WH',
    width: 200,
    ifShow: false
  },
  {
    title: bt('条码'),
    resizable: true,
    sorter: true,
    dataIndex: 'SN',
    width: 200,
  },
  // {
  //   title: bt('创建时间'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'CREATE_TIME',
  //   width: 180,
  // },
  {
    title: bt('修改时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'UPDATE_TIME',
    width: 180,
  },
  // {
  //   title: bt('单据代码'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'BILLCODE',
  //   width: 200,
  // },
  // {
  //   title: bt('单据日期'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'BILLDATE',
  //   width: 200,
  // },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('新增');
          color = 'blue';
          break;
        case 1:
          text = bt('作业中');
          color = '#C2C247';
          break;
        case 2:
          text = bt('完成');
          color = '#C2C247';
          break;
        case 3:
          text = bt('调拨完成');
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: bt('数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'QTY',
    width: 200,
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'OUTWAREHOUSECODE',
    label: bt('出库仓库'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'INWAREHOUSECODE',
    label: bt('入库仓库'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'LINESTATUS',
  //   label: bt('状态'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionsListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
  //     valueField: 'Value',
  //   },
  // }
];
export const searchFormSchema_S: FormSchema[] = [
  // {
  //   field: 'BILLCODE',
  //   label: bt('单据代码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'SN',
    label: bt('条码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'LINESTATUS',
  //   label: bt('状态'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionsListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
  //     valueField: 'Value',
  //   },
  // }
];
//新增组件
export const formSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: '单据代码',
    dynamicDisabled:true,
    //defaultValue:await CreateBillCode(),
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'STATUS',
    label: '状态',
    required: true,
    component: 'ApiSelect',
    defaultValue:-1,
    dynamicDisabled:true,
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  },
  {
    field: 'OUTWAREHOUSECODE',
    label: '调出仓库',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'INWAREHOUSECODE',
    label: '调入仓库',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'REMARK',
    label: '备注',
    // required: true,
    component: 'Input',
    colProps: { span: 12 },
    defaultValue:'手工下架',
    dynamicDisabled:true
  },
];